import { Entity } from '../../core.js';
import { SearchStrategy, SearchConfig } from '../types.js';
/**
 * Base class for search strategies with common functionality
 */
export declare abstract class BaseSearchStrategy implements SearchStrategy {
    protected config: SearchConfig;
    constructor(config: SearchConfig);
    abstract canUseDatabase(): boolean;
    abstract searchDatabase(query: string, threshold: number, project?: string): Promise<Entity[]>;
    abstract searchClientSide(entities: Entity[], query: string): Entity[];
    /**
     * Exact search implementation for backward compatibility
     */
    protected exactSearch(query: string, entities: Entity[]): Entity[];
    /**
     * Filter entities by exact tags
     */
    protected filterByExactTags(entities: Entity[], exactTags: string[], tagMatchMode?: 'any' | 'all'): Entity[];
}
//# sourceMappingURL=base-strategy.d.ts.map